/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */

#ifndef VNCVIEWERSETTINGSVIEW_H
#define VNCVIEWERSETTINGSVIEW_H

#include <AknView.h>
#include <aknsettingitemlist.h>
#include <aknnavide.h>
#include <akntabgrp.h>


class CVNCViewerSettingsContainer;
class CVNCViewerSettingsConnectList;
class CVNCViewerSettingsControlList;
class CVNCViewerSettingsViewList;
class CVNCViewerSettingsEncodingsList;
class CVNCViewerDocument;

/**
The settings view, consisting of 4 ages of controls.
*/
class CVNCViewerSettingsView : public CAknView
	{
public:
	static CVNCViewerSettingsView* NewLC(CVNCViewerDocument& aDocument);
	~CVNCViewerSettingsView();
	
	// from CAknView
	TUid Id() const;
	void HandleCommandL(TInt aCommand);
	
	void HandleStatusPaneSizeChange();

	void SizeChanged();

protected: 
	IMPORT_C virtual void DoActivateL(const TVwsViewId& aPrevViewId,
	                                  TUid aCustomMessageId,
	                                  const TDesC8& aCustomMessage);

    /** 
     * View deactivation function intended for overriding by sub classes. 
     * This function is called by @c AknViewDeactivated().
     */
	virtual void DoDeactivate();

	// Save the settings for the document	
	void SaveSettingsL();
		
private:
	CVNCViewerSettingsView(CVNCViewerDocument& aDocument);
	void ConstructL();
	
	CVNCViewerDocument&				iDocument;
	CVNCViewerSettingsContainer* 	iSettingsContainer;
	};


/**
The settings container
*/
class CVNCViewerSettingsContainer : public CCoeControl
{
public: // New methods

	/**
	 * NewL.
	 * Two-phased constructor.
	 * Create a CConnDetailsContainer object, which will draw itself to aRect.
	 * @param aRect The rectangle this view will be drawn to.
	 * @return a pointer to the created instance of CConnDetailsContainerw.
	 */
	static CVNCViewerSettingsContainer* NewL(const TRect& aRect, CVNCViewerDocument& aDocument);
	
	/**
	 * ~CConnDetailsContainer
	 * Virtual Destructor.
	 */
	virtual ~CVNCViewerSettingsContainer();

	TInt Port();

private:
	/**
	 * From CCoeControl, Draw
	 * Draw this CConnDetailsContainer to the screen.
	 * @param aRect the rectangle of this view that needs updating
	 */
	void Draw(const TRect& aRect) const;

	/**
	 * From CoeControl, SizeChanged.
	 * Called by framework when the view size is changed.
	 */
	virtual void SizeChanged();
	
	TInt CountComponentControls() const;
	CCoeControl* ComponentControl(TInt aIndex) const;
	
	TKeyResponse OfferKeyEventL(const TKeyEvent& aKeyEvent,TEventCode aType);
	
	void ChangeCurrentPage();
		
public:

private: // Constructors

	/**
	 * ConstructL
	 * 2nd phase constructor.
	 * Perform the second phase construction of a
	 * CConnDetailsContainer object.
	 * @param aRect The rectangle this view will be drawn to.
	 */
	void ConstructL(const TRect& aRect, CVNCViewerDocument& aDocument);

	/**
	 * CConnDetailsContainerAppView.
	 * C++ default constructor.
	 */
	CVNCViewerSettingsContainer();
	
private:	// Member variables
	CVNCViewerSettingsConnectList*		iSettingConnect;
	CVNCViewerSettingsControlList*		iSettingControl;
	CVNCViewerSettingsViewList*			iSettingView;
	CVNCViewerSettingsEncodingsList*	iSettingEncodings;
	
	CAknNavigationDecorator* 			iNaviDecorator;
	TInt 								iCurrentPage;
	};


/**
The settings connect list
*/
class CVNCViewerSettingsConnectList : public CAknSettingItemList
	{
public: // New methods
	CVNCViewerSettingsConnectList(CVNCViewerDocument& aDocument);
	void ConstructL();
	virtual ~CVNCViewerSettingsConnectList();

private:
	CAknSettingItem* CreateSettingItemL(TInt aIdentifier);
	
	void EditItemL (TInt aIndex,TBool aCalledFromMenu);
	
private:
	
private:
	CVNCViewerDocument& 				iDocument;
	CAknEnumeratedTextPopupSettingItem*	iViaControl;
	TInt								iVia;
	CDesCArray* 						iAccessPoints;
	};

/**
The settings control list
*/
class CVNCViewerSettingsControlList : public CAknSettingItemList
	{
public: // New methods
	CVNCViewerSettingsControlList(CVNCViewerDocument& aDocument);
	void ConstructL();
	
private:
	CAknSettingItem* CreateSettingItemL(TInt aIdentifier);
	
	void EditItemL (TInt aIndex,TBool aCalledFromMenu);
	
	// Update the option states
	void UpdateState();
	
private:
	CVNCViewerDocument& 	iDocument;
	CAknSettingItem*		iX11Cursor;
	};

/**
The settings view list
*/
class CVNCViewerSettingsViewList : public CAknSettingItemList
	{
public: // New methods
	CVNCViewerSettingsViewList(CVNCViewerDocument& aDocument);
	void ConstructL();
	
private:
	CAknSettingItem* CreateSettingItemL(TInt aIdentifier);
	
	void EditItemL (TInt aIndex,TBool aCalledFromMenu);
	
private:
	
private:
	CVNCViewerDocument& 	iDocument;
	};

/**
The settings encoding list
*/
class CVNCViewerSettingsEncodingsList : public CAknSettingItemList
	{
public: // New methods
	CVNCViewerSettingsEncodingsList(CVNCViewerDocument& aDocument);
	void ConstructL();
	
private:
	CAknSettingItem* CreateSettingItemL(TInt aIdentifier);
	
	void EditItemL (TInt aIndex,TBool aCalledFromMenu);
	
	// Update the option states
	void UpdateState();
	
private:
	CVNCViewerDocument& 	iDocument;
	CAknSettingItem*		iJpeg;
	CAknSettingItem*		iCompression;
	CAknSettingItem*		iQuality;
	};


#endif // VNCVIEWERSETTINGSVIEW_H
