/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */

#include <eikedwin.h>

#include "VNCScaleDialog.h"
#include "VNCViewer.hrh"
#include <VNCViewer.rsg>
#include <avkon.hrh>
#include <aknquerycontrol.h> 


/**
Creates, constructs, execute and destroys the dialog.

@param aStatus The request status to change
@param aScale The scale
*/
CVNCScaleDialog* CVNCScaleDialog::NewL(TRequestStatus& aStatus, TReal& aScale)
	{
	CVNCScaleDialog* self = new (ELeave) CVNCScaleDialog(aStatus, aScale);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop();
	return self;
	}

/**
Constructor for the dialog.

@param aStatus The request status to change
@param aScale The scale
*/
CVNCScaleDialog::CVNCScaleDialog(TRequestStatus& aStatus, TReal& aScale) 
	: CAknDialog(), iStatus(aStatus), iScale(aScale)
	{
	}

/**
Destructor for the dialog
*/
CVNCScaleDialog::~CVNCScaleDialog()
	{
	}

/**
2nd stage construction of the dialog.
*/
void CVNCScaleDialog::ConstructL()
	{
	}

/**
Handles all commands in the dialog.
Called by the UI framework when a command has been issued.
The command Ids are defined in the .hrh file.

@param aCommand The command to be executed
*/
TBool CVNCScaleDialog::OkToExitL(TInt aButtonId)
	{
	if (aButtonId == EAknSoftkeyOk)
		{
		CAknQueryControl* edwin = static_cast<CAknQueryControl*>(Control(EGeneralQuery));
		iScale = edwin->GetFloatingPointNumberL();

		TRequestStatus* status = &iStatus;
		User::RequestComplete(status, KErrNone);	
		}
	else
		{
		TRequestStatus* status = &iStatus;
		User::RequestComplete(status, KErrCancel);	
		}
	return ETrue;
	}

/**
Cancel the dialog
*/
void CVNCScaleDialog::Cancel()
	{
	TRequestStatus* status = &iStatus;
	User::RequestComplete(status, KErrCancel);	
	delete this;	
	}

/**
Prepare the dialog
*/
void CVNCScaleDialog::PreLayoutDynInitL()
	{
	CAknDialog::PreLayoutDynInitL();

	// Had to do this to force the number of lines to be 5
	CAknQueryControl* edwin = static_cast<CAknQueryControl*>(Control(EGeneralQuery));
	edwin->SetFloatingPointNumberL(&iScale);
	}

//---------------------------------------------------------------
//---------------------------------------------------------------

/**
Constructor for the active object.

@param aScaleCallback The callback object
@param aScale The initial scale
*/
CScaleActive* CScaleActive::NewL(MScale &aScaleCallback, TReal aScale)
	{
	CScaleActive* self = new(ELeave) CScaleActive(aScaleCallback, aScale);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Destrutor for the active object.
*/
CScaleActive::~CScaleActive()
	{
	Cancel();
	}

/**
Constructor for the active object.

@param aScale The callback object
@param aScale The initial scale
*/
CScaleActive::CScaleActive(MScale &aScaleCallback, TReal aScale)
: CActive(EPriorityStandard), iScaleCallback(aScaleCallback), iScale(aScale)
	{
	CActiveScheduler::Add(this);
	}

/**
2nd phase constructor
*/
void CScaleActive::ConstructL()
	{
	iScale *= 100;
	
	// Create the dialog
	iStatus = KRequestPending;
	iDialog = CVNCScaleDialog::NewL(iStatus, iScale);
	iDialog->ExecuteLD(R_VNCVIEWER_SCALE_DIALOG);
	SetActive();	
	}
	
/**
The dialog has completed
*/
void CScaleActive::RunL()
	{
	iScaleCallback.ScaleL(iStatus.Int(), iScale / 100);
	}
	
/**
The dialog needs to be cancelled
*/
void CScaleActive::DoCancel()
	{
	iDialog->Cancel();	
	iScaleCallback.ScaleL(KErrCancel, iScale);
	}
	
