/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */

#include "VNCViewerAppUi.h"
#include "VNCViewerSettingsView.h"
#include "VNCViewerVNCView.h"
#include "VNCViewerApplication.h"
#include "VNCViewerDocument.h"
#include "VNCViewerExternalInterface.h"

/**
2nd stage construction of the App UI.
Create view and add it to the framework.
The framework will take over the ownership.
*/
void CVNCViewerAppUi::ConstructL()
	{
	// Calls BaseConstructL that initiate the App UI.
	BaseConstructL(CAknViewAppUi::EAknEnableSkin);

	// Create the settings view and add it to the framework
	iActiveViewUid = KUidVNCViewerSettingsView;
	iVncViewerSettingsView = CVNCViewerSettingsView::NewLC(static_cast<CVNCViewerDocument&>(*Document()));
	AddViewL(iVncViewerSettingsView);
	CleanupStack::Pop(iVncViewerSettingsView);
	
	SetDefaultViewL(*iVncViewerSettingsView);

	// Create the VNC view and add it to the framework
	iVncViewerVNCView = CVNCViewerVNCView::NewLC(static_cast<CVNCViewerDocument&>(*Document()));
	AddViewL(iVncViewerVNCView);
	CleanupStack::Pop(iVncViewerVNCView);
	}

/**
Called when the application goes to the front or back. This triggers a 
selection copy

@param aForeground Foreground or Background?
*/
void CVNCViewerAppUi::HandleForegroundEventL(TBool aForeground)
	{
	// Call Base class method
	CAknAppUi::HandleForegroundEventL(aForeground);

	TUid currentViewUid = FocusedView();
	CAknView* active = View(currentViewUid);
	if ((active) && (active->ViewId().iViewUid == KUidVNCViewerVNCView))
		{
		CVNCViewerVNCView* vncView = (CVNCViewerVNCView*)active;
	   	vncView->HandleForegroundEventL(aForeground);
		}
 	}

/**
The destructor
*/
CVNCViewerAppUi::~CVNCViewerAppUi()
	{
	}
	
/**
Called when the resource changes, such as a rotation

@param aType The type of the resource change
*/
void CVNCViewerAppUi::HandleResourceChangeL(TInt aType)
	{
	CAknAppUi::HandleResourceChangeL(aType);

	iVncViewerSettingsView->SizeChanged();
	iVncViewerVNCView->SizeChanged();
	}

/**
Called to set the active view

@param aView The view
*/
void CVNCViewerAppUi::SetActiveView(TUid aUid)
	{
	iActiveViewUid = aUid;
	}
		
/**
Called to handle a command

@param aType The type of the resource change
*/
void CVNCViewerAppUi::HandleCommandL(TInt aCommand)
    {
    CAknView* view = View(iActiveViewUid);
    if (view)
    	{
	   	view->HandleCommandL(aCommand);
		}
    }