/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */

#include <eikstart.h>
#include "VNCViewerApplication.h"
#include "VNCViewerDocument.h"
#include "VNCViewerExternalInterface.h" // contains the applications UID

/**
The function is called by the UI framework to ask for the 
application's UID. The returned value is defined by the 
constant KUidVNCViewerApp and must match the second value 
defined in the project definition file.

@return TUid The application UID
*/
TUid CVNCViewerApplication::AppDllUid() const
	{
	return KUidVNCViewerApp;
	}

/**
This function is called by the UI framework at application start-up. 
It creates an instance of the document class.

@return CApaDocument* The new document
*/
CApaDocument* CVNCViewerApplication::CreateDocumentL()
	{
	return CVNCViewerDocument::NewL(*this);
	}

/**
The function is called by the framework immediately after it has started the 
application's EXE. It is called by the framework and is expected to have 
exactly this prototype.
Function is a non-leaving function, this because we need to create the 
application object or return NULL on failure. Therefore we cant use the 
new(ELeave) operator.

@return Instance of the application class.
*/
CApaApplication* NewApplication()
	{
	return new CVNCViewerApplication;
	}

CDictionaryStore* CVNCViewerApplication::OpenIniFileLC(RFs& aFs) const
	{
	return CEikApplication::OpenIniFileLC(aFs);
	}

/**
E32Main() contains the program's start up code, the entry point for an EXE.
*/
GLDEF_C TInt E32Main()
	{
	return EikStart::RunApplication(NewApplication);
	}
