/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */


#ifndef VNCVIEWERVNCVIEW_H
#define VNCVIEWERVNCVIEW_H

#include <QikMultiPageViewBase.h>
#include <QikScrollableContainer.h>
#include <QUiConfigClient.h>
#include <EIKSBFRM.H>
#include <BITSTD.H>
#include "VNCViewMsg.h"
#include "VNCSendTextDialog.h"
#include "VNCScaleDialog.h"

// Forward declarations
class CVNCViewerScrollableContainer;
class CVNCViewportWindow;
class CVNCViewerDocument;

/**
The VNC view 
*/
class CVNCViewerVNCView : public CQikViewBase
	{
public:
	static CVNCViewerVNCView* NewLC(CQikAppUi& aAppUi);
	virtual ~CVNCViewerVNCView();
	
	// from CQikViewBase
	TVwsViewId ViewId()const;
	void HandleCommandL(CQikCommand& aCommand);
	
	void HandleForegroundEventL(TBool aForeground);
	
	void HandleUiConfigChangedL();

	void SizeChanged();
	
	void QuitNow();
	void DestroyEngine(TBool aSwitchView);
	void Shutdown();
	
protected: // from CQikViewBase
	void ViewActivatedL(const TVwsViewId& aPrevViewId, const TUid aCustomMessageId, const TDesC8& aCustomMessage);
	void ViewConstructL(); 

private:
	CVNCViewerVNCView(CQikAppUi& aAppUi);
	void ConstructL();

private:
	CQUiConfigClient&				iConfigClient;
	CVNCViewerScrollableContainer*	iVNCContainer;
	TBool							iNeedToConnect;
	TBool							iExiting;
	};

/**
The VNC container, this is a scrollable window which contains the engine
*/
class CVNCViewerScrollableContainer : public CQikScrollableContainer, public MVNCViewerEvent, public MSendText, public MScale
	{
public:
	enum TButtonMode
		{
		EButtonLeft,
		EButtonMiddle,
		EButtonRight
		};

	CVNCViewerScrollableContainer(CVNCViewerVNCView& aView, CVNCViewerDocument& aDocument);
	void ConstructL(const TRect& aRect);
	virtual ~CVNCViewerScrollableContainer();

	void ConnectL();
	void SetScaleL(TReal aScale);
	void SetCustomScaleL();
	void SetButtonMode(TButtonMode aButtonMode);
	void HandleForegroundEventL(TBool aForeground);
	void SendTextDialogL();
	TBool SendKeyL(TInt aKey);
	void RefreshL();
	void SetArrowKeysControlCursor(TBool aOn);
	void FindCursorL();
	void Destroy();
	TBool LoggedOn() { return iLoggedOn; };
	void SizeChanged();

	// from MVCViewerEvent
	HBufC8* ShowPasswordL();
	void CreateBitmapL(TInt aHandle);
	void PutImage(const TRect& aRect);
	void EngineQuit();
	void ServerMessageL(const TDesC& aMessage);
	void MoveSoftCursorL(TInt aX, TInt aY);	
	RWsSprite* CreatePixmapCursorL(TInt aBitmapHandle, TInt aMaskHandle, TInt aHotpointX, TInt aHotpointY);	
	void WarpPointerL(TInt aCursorX, TInt aCursorY);
	void FreeCursorL();

	// From MSendText	
	void SendTextL(TInt aErr, const TDesC& aText);	

	// From MScale	
	void ScaleL(TInt aCmd, const TReal aScale);	

	const CFbsBitmap* Bitmap() const
	{
		return iMainBitmap;
	};

	void HandlePointerEventL(const TPointerEvent& aPointerEvent);
	TKeyResponse OfferKeyEventL(const TKeyEvent &aKeyEvent, TEventCode aType);	
	
	TBool PostQuit();
	
	void Draw(const TRect& aRect) const;
		
private:
	TSize ViewPortSize();
	TBool CursorInScreenArea();
	void MimicPointerMoveL(TBool aScroll);
	void MimicPointerDownUpL(TBool aDown);
	void TranslateRemoteToLocalPoint(TPoint& aPoint);
	void TranslateLocalToRemotePoint(TPoint& aPoint);
	TRect ScaledRect(const TRect& aRect);
	
private:
	CVNCViewerVNCView& 			iView;
//	CQikAppUi&					iAppUi;	
	CVNCViewerDocument&			iDocument;
	TBool						iArrowKeypressMovesPointer;
	TInt						iPointerAcceleration;
	TBool						iCursorLocated;
	CVNCViewportWindow*			iVNCViewPortWindow;
	CVNCViewMsgProcessor*		iVNCViewMsgProc;
	CFbsBitmap*					iMainBitmap;
	CSendTextActive*			iSendTextActive;
	TButtonMode					iButtonMode;
	TBool						iLoggedOn;
	TBool						iCursorCreated;
	TPoint 						iCursorPos;
	RWsSprite					iCursor;
	CFbsBitmap*					iCursorBitmap;
	CFbsBitmap*					iCursorMask;
	CScaleActive*				iScaleActive;
	TReal						iScale;
	TBool						iPointerDown;
	};


/**
The VNC viewport, this contains the main image window 
*/
class CVNCViewportWindow : public CCoeControl
	{
public:
	static CVNCViewportWindow* NewL(CVNCViewerScrollableContainer& aViewport);
	virtual ~CVNCViewportWindow();

	void HandlePointerEventL(const TPointerEvent& aPointerEvent);
					
private:
	CVNCViewportWindow(CVNCViewerScrollableContainer& aViewport);
	void ConstructL();
	
	void Draw(const TRect& aRect) const;
	
private:
	CVNCViewerScrollableContainer& 	iViewport;
	};


#endif // VNCVIEWERVNCVIEW_H
