/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */

/*
 * x11JpegConvert.cpp - Convert JPEG data
 */

#include "x11JpegConvert.h"
	
/**
Convert JPEG data into a bitmap
@param aFs A file server session
@param aData The data to convert
@param aBitmap The bitmap to convert into
*/
void CJpegConverter::ConvertL(RFs& aFs, const TDesC8& aData, CFbsBitmap* aBitmap)
	{
	CJpegConverter* converter = new(ELeave) CJpegConverter();
	CleanupStack::PushL(converter);
	converter->InternalConvertL(aFs, aData, aBitmap);
	User::LeaveIfError(converter->ErrorCode());
	CleanupStack::PopAndDestroy(converter);
	}

/**
Constructor for the converter
*/
CJpegConverter::CJpegConverter()
: CActive(EPriorityStandard)
	{
	CActiveScheduler::Add(this);
	}
	
/**
Destructor
*/
CJpegConverter::~CJpegConverter()
	{
	delete iDecoder;
	}
	
/**
The conversion is complete
*/
void CJpegConverter::RunL()
	{
	CActiveScheduler::Stop();
	}
	
/**
Cancel the conversion
*/
void CJpegConverter::DoCancel()
	{
	iDecoder->Cancel();
	}

/**
Do the conversion
@param aFs A file server session
@param aData The data to convert
@param aBitmap The bitmap to convert into
*/
void CJpegConverter::InternalConvertL(RFs& aFs, const TDesC8& aData, CFbsBitmap* aBitmap)
	{
	// Create the decoder
	_LIT8(KJpegType, "image/jpeg");
	iDecoder = CImageDecoder::DataNewL(aFs, aData, KJpegType);

	// Convert the bitmap	
	iDecoder->Convert(&iStatus, *aBitmap);
	SetActive();
	
	// Start the conversion
	CActiveScheduler::Start();
	}

