/*
 *  Copyright (C) 2007 Rob Cliff.  All Rights Reserved.
 *  Copyright (C) 2007 Savage Minds Ltd.  All Rights Reserved.
 *
 *  This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 *  USA.
 */

/*
 * x11NVPair.cpp - Name value pair
 */

#include "x11NVPair.h"


/**
Construct a name value pair
@param aName The name to copy
@param aValue The value to copy
@return CNVPairDes* The name value pair
*/
CNVPairDes* CNVPairDes::NewL(const TDesC8& aName, const TDesC8& aValue)
	{
	CNVPairDes* nvpair = new(ELeave) CNVPairDes();
	CleanupStack::PushL(nvpair);
	nvpair->ConstructL(aName, aValue);
	CleanupStack::Pop(nvpair);
	return nvpair;
	}
	
/**
Construct a name value pair
@param aName The name to copy
@return CNVPairDes* The name value pair
*/
CNVPairDes* CNVPairDes::NewL(const TDesC8& aName)
	{
	return CNVPairDes::NewL(aName, KNullDesC8);
	}
	
/**
Destructor
*/
CNVPairDes::~CNVPairDes() 
	{
	delete iName;
	delete iValue;
	}

/**
Set the value of the name-value pair
@param aValue The value
*/
void CNVPairDes::SetValueL(const TDesC8& aValue)
	{
	HBufC8* value = aValue.AllocL();
	delete iValue;
	iValue = value;
	}
	
/**
Return the name
@return const TDesC8& The name
*/
const TDesC8& CNVPairDes::Name()	
	{
	return *iName;
	}
	
/**
Return the value
@return const TDesC8& The value
*/
const TDesC8& CNVPairDes::Value()
	{
	return *iValue;
	}
		
/**
2nd phase constructor
@param aName The name
@param aValue The value
*/
void CNVPairDes::ConstructL(const TDesC8& aName, const TDesC8& aValue)
	{
	iName = aName.AllocL();
	iValue = aValue.AllocL();
	}

